#! /usr/bin/env python
#
# Copyright INRA-URGI 2009-2011
# 
# This software is governed by the CeCILL license under French law and
# abiding by the rules of distribution of free software. You can use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
# 
# As a counterpart to the access to the source code and rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty and the software's author, the holder of the
# economic rights, and the successive licensors have only limited
# liability.
# 
# In this respect, the user's attention is drawn to the risks associated
# with loading, using, modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean that it is complicated to manipulate, and that also
# therefore means that it is reserved for developers and experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and, more generally, to use and operate it in the
# same conditions as regards security.
# 
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.
#
import os, random
from optparse import OptionParser, OptionGroup
from SMART.Java.Python.structure.TranscriptContainer import TranscriptContainer
from SMART.Java.Python.misc.Progress import Progress
from SMART.Java.Python.misc.UnlimitedProgress import UnlimitedProgress
from commons.core.writer.Gff3Writer import Gff3Writer

NB_FILES = 2
NB_LINES = 4

class InterleaveFastq(object):

	def __init__(self, verbosity = 0):
		self.verbosity = verbosity
		self.parsers   = [None, None]

	def setInputFileName(self, fileName, index):
		self.parsers[index] = open(fileName)
	
	def setOutputFileName(self, fileName):
		self.writer = open(fileName, "w")

	def getLines(self, parser):
		lines = ""
		for i in range(NB_LINES):
			line = parser.readline()
			if not line:
				return False
			lines += line
		return lines

	def run(self):
		lines    = [self.getLines(self.parsers[i]) for i in range(NB_FILES)]
		progress = UnlimitedProgress(100000, "Writing file", self.verbosity)
		while lines[0]:
			for i in range(NB_FILES):
				self.writer.write(lines[i])
			lines = [self.getLines(self.parsers[i]) for i in range(NB_FILES)]
			progress.inc()
		progress.done()

if __name__ == "__main__":
	
	# parse command line
	description = "Interleave Fastq v1.0.1: Interleave Fastq files. [Category: Personal]"

	parser = OptionParser(description = description)
	parser.add_option("-1", "--input1",	   dest="inputFileName1", action="store", type="string", help="left read file [compulsory] [format: file in FASTQ format]")
	parser.add_option("-2", "--input2",	   dest="inputFileName2", action="store", type="string", help="right read file [compulsory] [format: file in FASTQ format]")
	parser.add_option("-o", "--output",	   dest="outputFileName", action="store", type="string", help="output file [format: output file in FASTQ format]")
	parser.add_option("-v", "--verbosity", dest="verbosity",	  action="store", type="int",    help="trace level [default: 1] [format: int]")
	(options, args) = parser.parse_args()

	interleave = InterleaveFastq(options.verbosity)
	interleave.setInputFileName(options.inputFileName1, 0)
	interleave.setInputFileName(options.inputFileName2, 1)
	interleave.setOutputFileName(options.outputFileName)
	interleave.run()
